Wayfarer
========

| |Coveralls|

A Python library for creating and analysing geospatial networks using `NetworkX <https://networkx.org/>`_.

For an overview presentation see https://compassinformatics.github.io/wayfarer-presentation/

..
    https://networkx.org/documentation/stable/reference/algorithms/generated/networkx.algorithms.components.is_strongly_connected.html#networkx.algorithms.components.is_strongly_connected
    

.. |Coveralls| image:: https://coveralls.io/repos/github/compassinformatics/wayfarer/badge.svg?branch=main
    :target: https://coveralls.io/github/compassinformatics/wayfarer?branch=main